import java.util.*;
import java.net.*;
import org.apache.soap.*;
import org.apache.soap.rpc.*;

public class ConverterClient
{
	public static void main(String[] args)
	{
		try
		{
			checkUsage(args);
			
			URL theURL = new URL(args[0]);
			
			// First build the call
			Call theCall = new Call();
			theCall.setTargetObjectURI("urn:temperatureConverter");
			theCall.setMethodName(args[1]);
			theCall.setEncodingStyleURI(Constants.NS_URI_SOAP_ENC);
			Vector theParameters = new Vector();
			theParameters.add(new Parameter("value", Double.TYPE, args[2], null));
			theCall.setParams(theParameters);
			
			// Make the call
			Response theResponse = theCall.invoke(theURL, ""/* no action url required */);
			
			// Check for errors
			if (theResponse.generatedFault())
			{
				Fault theFault = theResponse.getFault();
				System.out.println("Fault code: " +
						theFault.getFaultCode());
				System.out.println("Fault string: " + 
						theFault.getFaultString());
			}
			else
			{	// Process response
				Parameter theResult = theResponse.getReturnValue();
				System.out.println(theResult.getValue());
			}
		}
		catch(Throwable t)
		{
			System.out.println("Error occured: " + t);
			t.printStackTrace();
		}
	}

	public static void checkUsage(String[] args)
	{
		if (args.length == 3)
		{
				try
				{
					Double.parseDouble(args[2]);
					return;
				}
				catch(Exception e)
				{
					System.out.println("temperatureValue must be real number");
				}
		}
		
		System.out.println("Usage:");
		System.out.println("java " + 
				ConverterClient.class.getName() + 
				" http://hostName:8080/soap/servlet/rpcrouter c2f temperatureValue");
		System.out.println("java " + 
				ConverterClient.class.getName() + 
				" http://hostName:8080/soap/servlet/rpcrouter f2c temperatureValue");
				
		System.exit(0);
	}
}
